@@ -1,6 +1,6 @@
 /*
  *  Jajuk
- *  Copyright (C) 2003-2010 The Jajuk Team
+ *  Copyright (C) 2003-2011 The Jajuk Team
  *  http://jajuk.info
  *
  *  This program is free software; you can redistribute it and/or
@@ -16,7 +16,7 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- *  $Revision: 6186 $
+ *  $Revision$
  */
 package org.jajuk.base;
 
@@ -25,6 +25,7 @@ import java.awt.image.BufferedImage;
 import java.io.File;
 import java.io.IOException;
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.Date;
 import java.util.HashSet;
 import java.util.List;
@@ -35,6 +36,9 @@ import javax.imageio.ImageIO;
 import javax.swing.ImageIcon;
 
 import org.apache.commons.lang.StringUtils;
+import org.jajuk.base.TrackComparator.TrackComparatorType;
+import org.jajuk.services.covers.Cover;
+import org.jajuk.services.tags.Tag;
 import org.jajuk.ui.thumbnails.ThumbnailManager;
 import org.jajuk.util.Const;
 import org.jajuk.util.IconLoader;
@@ -43,6 +47,7 @@ import org.jajuk.util.JajukIcons;
 import org.jajuk.util.Messages;
 import org.jajuk.util.UtilFeatures;
 import org.jajuk.util.UtilString;
+import org.jajuk.util.error.JajukException;
 import org.jajuk.util.filters.ImageFilter;
 import org.jajuk.util.log.Log;
 
@@ -128,14 +133,24 @@ public class Album extends LogicalItem implements Comparable<Album> {
   }
 
   /**
-   * Checks if is unknown.
+   * Return whether this item is strictly unknown : contains no tag
    * 
-   * @return whether the album is Unknown or not
+   * @return whether this item is Unknown or not
    */
   public boolean isUnknown() {
     return this.getName().equals(UNKNOWN_ALBUM);
   }
 
+  /**
+  * Return whether this item seems unknown (fuzzy search)
+  * 
+  * @return whether this item seems unknown
+  */
+  public boolean seemsUnknown() {
+    return isUnknown() || "unknown".equalsIgnoreCase(getName())
+        || Messages.getString(UNKNOWN_ALBUM).equalsIgnoreCase(getName());
+  }
+
   /*
    * (non-Javadoc)
    * 
@@ -280,35 +295,42 @@ public class Album extends LogicalItem implements Comparable<Album> {
   }
 
   /**
-   * Gets the cover file.
+   * Gets the best associated cover as a file.
    * <p>Can be a long action</p>
    * 
-   * @return associated best cover file available or null if none. The returned
-   * file can not be readable, so use a try/catch around a future access to it.
+   * @return Associated best cover file available or null if none. The returned
+   * file is not guarantee to exist, so use a try/catch around a future access to this method.
    */
-  public File findCoverFile() {
-    String cachedCoverPath = getStringValue(XML_ALBUM_COVER);
-    if (COVER_NONE.equals(cachedCoverPath)) {
+  public File findCover() {
+    String discoveredCoverPath = getStringValue(XML_ALBUM_DISCOVERED_COVER);
+    String selectedCoverPath = getStringValue(XML_ALBUM_SELECTED_COVER);
+    if (StringUtils.isNotBlank(selectedCoverPath) && new File(selectedCoverPath).exists()) {
+      // If user-selected cover is available, just return its path
+      return new File(selectedCoverPath);
+    } else if (StringUtils.isNotBlank(discoveredCoverPath) && COVER_NONE.equals(discoveredCoverPath)) {
       return null;
-    } else if (!StringUtils.isBlank(cachedCoverPath)) {
-      // Check if cover still exist. There is an overhead
+    } else if (StringUtils.isNotBlank(discoveredCoverPath)) {
+      // Check if discovered cover still exist. There is an overhead
       // drawback but otherwise, the album's cover
       // property may be stuck to an old device's cover url.
-      Device device = DeviceManager.getInstance().getDeviceByPath(new File(cachedCoverPath));
+      // Moreover, cover tags are extracted to cache directory so they are 
+      // Regularly dropped.
+      Device device = DeviceManager.getInstance().getDeviceByPath(new File(discoveredCoverPath));
       // If the device is not mounted, do not perform this existence check up
       if (device != null && device.isMounted()) {
-        if (new File(cachedCoverPath).exists()) {
-          return new File(cachedCoverPath);
+        if (new File(discoveredCoverPath).exists()) {
+          return new File(discoveredCoverPath);
         }
       } else {
-        return new File(cachedCoverPath);
+        return new File(discoveredCoverPath);
       }
     }
-    // search for local covers in all directories mapping the current track
+    // None cover yet set or it is no more accessible.
+    // Search for local covers in all directories mapping the current track
     // to reach other devices covers and display them together
     List<Track> lTracks = cache;
     if (lTracks.size() == 0) {
-      setProperty(XML_ALBUM_COVER, COVER_NONE);
+      setProperty(XML_ALBUM_DISCOVERED_COVER, COVER_NONE);
       return null;
     }
     // List at directories we have to look in
@@ -325,21 +347,66 @@ public class Album extends LogicalItem implements Comparable<Album> {
       return null;
     }
 
-    // look for standard cover in collection
-    File cover = findCover(dirs, true);
+    // look for tag cover
+    File cover = findTagCover();
+
+    // none ? look for standard cover in collection
+    if (cover == null) {
+      cover = findCoverFile(dirs, true);
+    }
 
     // none ? OK, return first cover file we find
     if (cover == null) {
-      cover = findCover(dirs, false);
+      cover = findCoverFile(dirs, false);
     }
 
-    // Still nothing ? ok, set no cover
+    // [PERF] Still nothing ? ok, set no cover to avoid further searches 
     if (cover == null) {
-      setProperty(XML_ALBUM_COVER, COVER_NONE);
+      setProperty(XML_ALBUM_DISCOVERED_COVER, COVER_NONE);
+    } else { //[PERF] if we found a cover, we store it to avoid further covers 
+      // searches including a full tags picture extraction  
+      setProperty(XML_ALBUM_DISCOVERED_COVER, cover.getAbsolutePath());
     }
     return cover;
   }
 
+  /**
+   * Return whether this album owns a cover (this method doesn't check
+   * cover file existence). 
+   * @return whether this album owns a cover.
+   */
+  public boolean containsCover() {
+    String discoveredCoverPath = getStringValue(XML_ALBUM_DISCOVERED_COVER);
+    return !StringUtils.isBlank(discoveredCoverPath) && !discoveredCoverPath.equals(COVER_NONE);
+  }
+
+  /**
+   * Return a tag cover file from given directories. If a cover tags are found, 
+   * they are extracted to the cache directory. 
+   * 
+   * @return a tag cover file or null if none.
+   */
+  private File findTagCover() {
+    //Make sure to sort the cache
+    List<Track> sortedTracks = new ArrayList<Track>(cache);
+    Collections.sort(sortedTracks, new TrackComparator(TrackComparatorType.ALBUM));
+
+    for (Track track : sortedTracks) {
+      for (org.jajuk.base.File file : track.getReadyFiles()) {
+        try {
+          Tag tag = new Tag(file.getFIO(), false);
+          List<Cover> covers = tag.getCovers();
+          if (covers.size() > 0) {
+            return covers.get(0).getFile();
+          }
+        } catch (JajukException e1) {
+          Log.error(e1);
+        }
+      }
+    }
+    return null;
+  }
+
   /**
    * Return a cover file matching criteria or null.
    * 
@@ -348,7 +415,7 @@ public class Album extends LogicalItem implements Comparable<Album> {
    * 
    * @return a cover file matching criteria or null
    */
-  private File findCover(Set<Directory> dirs, boolean onlyStandardCovers) {
+  private File findCoverFile(Set<Directory> dirs, boolean onlyStandardCovers) {
     JajukFileFilter filter = new JajukFileFilter(ImageFilter.getInstance());
     for (Directory dir : dirs) {
       File fDir = dir.getFio(); // store this dir
@@ -371,7 +438,6 @@ public class Album extends LogicalItem implements Comparable<Album> {
             // Note that at this point, the image is fully loaded (done in the ImageIcon
             // constructor)
             if (ii.getImageLoadStatus() == MediaTracker.COMPLETE) {
-              setProperty(XML_ALBUM_COVER, files[i].getAbsolutePath());
               return files[i];
             } else {
               Log.debug("Problem loading: " + files[i].getAbsolutePath());
