@@ -1,6 +1,6 @@
 /*
  *  Jajuk
- *  Copyright (C) 2003-2010 The Jajuk Team
+ *  Copyright (C) 2003-2011 The Jajuk Team
  *  http://jajuk.info
  *
  *  This program is free software; you can redistribute it and/or
@@ -16,13 +16,14 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- *  $Revision: 6186 $
+ *  $Revision$
  */
 package org.jajuk.base;
 
 import java.io.File;
 import java.util.ArrayList;
 import java.util.Date;
+import java.util.HashSet;
 import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Set;
@@ -355,6 +356,30 @@ public class Directory extends PhysicalItem implements Comparable<Directory> {
     }
     // Clear the tag cache so tags are actually read at next deep refresh
     Tag.clearCache();
+
+    // Force cover detection (after done once, the cover file is cached as album property)
+    // We need this to avoid bug #1550 : if the device is created, then unplugged, catalog
+    // view cover/no-cover filter is messed-up because the findCover() method always return null.
+    Set<Album> albumsToCheck = getAlbums();
+    for (Album album : albumsToCheck) {
+      album.findCover();
+    }
+  }
+
+  /**
+   * Return list of albums for current directory.
+   * 
+   * @param 
+   * 
+   * @return list of albums for current directory
+   */
+  public Set<Album> getAlbums() {
+    Set<Album> out = new HashSet<Album>(1);
+    Set<org.jajuk.base.File> files = this.getFiles();
+    for (org.jajuk.base.File file : files) {
+      out.add(file.getTrack().getAlbum());
+    }
+    return out;
   }
 
   /**
