@@ -1,6 +1,6 @@
 /*
  *  Jajuk
- *  Copyright (C) 2003-2010 The Jajuk Team
+ *  Copyright (C) 2003-2011 The Jajuk Team
  *  http://jajuk.info
  *
  *  This program is free software; you can redistribute it and/or
@@ -16,7 +16,7 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- *  $Revision: 6186 $
+ *  $Revision$
  */
 package org.jajuk.base;
 
@@ -290,7 +290,7 @@ public class File extends PhysicalItem implements Comparable<File>, Const {
     // files). This allow cleaning old tracks after a change of tags from others
     // programs than jajuk
     if (!this.track.equals(track)) {
-      TrackManager.getInstance().removefile(this.track, this);
+      TrackManager.getInstance().removeFile(this);
       this.track = track;
       setProperty(Const.XML_TRACK, track.getID());
     }
