@@ -1,6 +1,6 @@
 /*
  *  Jajuk
- *  Copyright (C) 2003-2010 The Jajuk Team
+ *  Copyright (C) 2003-2011 The Jajuk Team
  *  http://jajuk.info
  *
  *  This program is free software; you can redistribute it and/or
@@ -16,7 +16,7 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- *  $Revision: 6186 $
+ *  $Revision$
  */
 package org.jajuk.services.players;
 
@@ -241,8 +241,7 @@ public final class Player {
    * 
    * @throws Exception    */
   public static void mute() {
-    Player.bMute = !Player.bMute;
-    mute(Player.bMute);
+    mute(!Player.bMute);
   }
 
   /**
@@ -253,7 +252,8 @@ public final class Player {
    * @throws Exception    */
   public static void mute(boolean pMute) {
     try {
-      if (playerImpl == null) { // none current player, leave
+      if (playerImpl == null) { // none current player, set mute state and leave
+        Player.bMute = pMute;
         return;
       }
       if (pMute) {
