@@ -1,6 +1,6 @@
 /*
  *  Jajuk
- *  Copyright (C) 2003-2010 The Jajuk Team
+ *  Copyright (C) 2003-2011 The Jajuk Team
  *  http://jajuk.info
  *
  *  This program is free software; you can redistribute it and/or
@@ -16,7 +16,7 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- *  $Revision: 6186 $
+ *  $Revision$
  */
 
 package org.jajuk.ui.views;
@@ -27,6 +27,7 @@ import java.awt.Color;
 import java.awt.Dimension;
 import java.awt.FlowLayout;
 import java.awt.Insets;
+import java.awt.KeyboardFocusManager;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.ComponentListener;
@@ -73,8 +74,8 @@ import org.jajuk.events.JajukEvents;
 import org.jajuk.events.ObservationManager;
 import org.jajuk.ui.helpers.DefaultMouseWheelListener;
 import org.jajuk.ui.helpers.FontManager;
-import org.jajuk.ui.helpers.TwoStepsDisplayable;
 import org.jajuk.ui.helpers.FontManager.JajukFont;
+import org.jajuk.ui.helpers.TwoStepsDisplayable;
 import org.jajuk.ui.thumbnails.LocalAlbumThumbnail;
 import org.jajuk.ui.thumbnails.ThumbnailManager;
 import org.jajuk.ui.widgets.InformationJPanel;
@@ -488,11 +489,10 @@ public class CatalogView extends ViewAdapter implements ComponentListener, Actio
       while (itAlbums.hasNext()) {
         Album album = itAlbums.next();
         if (jcbShowCover.getSelectedIndex() == Const.CATALOG_VIEW_COVER_MODE_WITH
-            && album.findCoverFile() == null) {
+            && !album.containsCover()) {
           itAlbums.remove();
-        }
-        if (jcbShowCover.getSelectedIndex() == Const.CATALOG_VIEW_COVER_MODE_WITHOUT
-            && album.findCoverFile() != null) {
+        } else if (jcbShowCover.getSelectedIndex() == Const.CATALOG_VIEW_COVER_MODE_WITHOUT
+            && album.containsCover()) {
           itAlbums.remove();
         }
       }
@@ -666,7 +666,6 @@ public class CatalogView extends ViewAdapter implements ComponentListener, Actio
         || JajukEvents.DEVICE_MOUNT.equals(subject) || JajukEvents.DEVICE_UNMOUNT.equals(subject)
         || JajukEvents.PARAMETERS_CHANGE.equals(subject)) {
       SwingUtilities.invokeLater(new Runnable() {
-
         @Override
         public void run() {
           populateCatalog();
@@ -707,8 +706,8 @@ public class CatalogView extends ViewAdapter implements ComponentListener, Actio
       lDateTyped = System.currentTimeMillis();
       Conf.setProperty(Const.CONF_THUMBS_SORTER, Integer.toString(jcbSorter.getSelectedIndex()));
     } else if (e.getSource() == jcbShowCover) {
-      Conf.setProperty(Const.CONF_THUMBS_SHOW_COVER, Integer.toString(jcbShowCover
-          .getSelectedIndex()));
+      Conf.setProperty(Const.CONF_THUMBS_SHOW_COVER,
+          Integer.toString(jcbShowCover.getSelectedIndex()));
       // Reset page to zero to avoid out of bounds exceptions, when restricting
       // the filter, less pages are available
       page = 0;
@@ -829,7 +828,7 @@ public class CatalogView extends ViewAdapter implements ComponentListener, Actio
 
     // we specifically request the focus for jtfValue, therefore we should make sure that we release
     // that focus to let this be destroyed
-    FocusManager.getCurrentKeyboardFocusManager().clearGlobalFocusOwner();
+    KeyboardFocusManager.getCurrentKeyboardFocusManager().clearGlobalFocusOwner();
 
     // call the parent class to do more cleanup if necessary
     super.cleanup();
