@@ -282,7 +282,11 @@ public final class Log {
       return;
     }
     spool(t);
-    logger.log(FULL_QUALIFIED_CLASS_NAME, Level.ERROR, t.getMessage() + " / " + t.getCause(), t);
+    if (t.getCause() != null) {
+      logger.log(FULL_QUALIFIED_CLASS_NAME, Level.ERROR, t.getMessage() + " / " + t.getCause(), t);
+    } else {
+      logger.log(FULL_QUALIFIED_CLASS_NAME, Level.ERROR, t.getMessage(), t);
+    }
   }
 
   /**
@@ -425,8 +429,12 @@ public final class Log {
    * @param e DOCUMENT_ME
    */
   private static void spool(Throwable e) {
-    spool("<font color='red'>" + "[ERROR] " + e.getClass() + " / {{" + e.getMessage() + "}} / "
-        + e.getCause());
+    if (e.getCause() != null) {
+      spool("<font color='red'>" + "[ERROR] " + e.getClass() + " / {{" + e.getMessage() + "}} / "
+          + e.getCause());
+    } else {
+      spool("<font color='red'>" + "[ERROR] " + e.getClass() + " / {{" + e.getMessage() + "}}");
+    }
     StackTraceElement[] ste = e.getStackTrace();
     for (StackTraceElement element : ste) {
       spool(element.toString());
